@@ -10,7 +10,13 @@
 #import <sys/param.h> /* for MAXPATHLEN */
 #import <unistd.h>
 
+#include <Security/Authorization.h>
+#include <Security/AuthorizationTags.h>
+#include <fontconfig/fontconfig.h>
+#include <stdlib.h>
+
 #import "macosx_print.h"
+#import "message.h"
 #import "wrapperdata.h"
 
 /* For some reaon, Apple removed setAppleMenu from the headers in 10.4,
@@ -46,6 +52,7 @@ static BOOL   gFinderLaunch;
 static BOOL   gCalledAppMainline = FALSE;
 
 WrapperData macosx; 
+SDLMain *sdlMain;
 
 static NSString *getApplicationName(void)
 {
@@ -82,7 +89,9 @@ static NSString *getApplicationName(void)
 		if (NSKeyDown == [anEvent type] || NSKeyUp == [anEvent type])
 		{
 			if( ( [anEvent modifierFlags] & NSCommandKeyMask ) == 0 ) 
+            {
 				return;		// do not intercept keystrokes intended for SDL layer
+            }
 		}
 	}
 	[super sendEvent: anEvent];
@@ -116,29 +125,32 @@ static NSString *getApplicationName(void)
 
 -(void) dataPath:(NSString *)directory;
 {
-  NSBundle *mainBundle;
-  NSString *path;
-  
-  mainBundle = [NSBundle mainBundle];
-  path = [mainBundle pathForResource:@"data" ofType:nil];
+    NSBundle *mainBundle;
+    NSString *path;
 
-  [path getCString:(macosx.dataPath)];
+    mainBundle = [NSBundle mainBundle];
+    path = [mainBundle pathForResource:@"data" ofType:nil];
+
+    [path getCString:(macosx.dataPath)];
 }
 
 -(void) preferencesPath;
 {
-  NSString *path;
-  
-  path = [@"~/Library/Application Support" stringByExpandingTildeInPath];
-  [path getCString:(macosx.preferencesPath)];
+    NSString *path;
+
+    path = [@"~/Library/Application Support/TuxPaint" stringByExpandingTildeInPath];
+    [path getCString:(macosx.preferencesPath)];
+
+    path = @"/Library/Application Support/TuxPaint";
+    [path getCString:(macosx.globalPreferencesPath)];
 }
 
 -(void) fontsPath;
 {
-  NSString *path;
-  
-  path = [@"~/Library/Fonts" stringByExpandingTildeInPath];
-  [path getCString:(macosx.fontsPath)];
+    NSString *path;
+
+    path = [@"~/Library/Fonts" stringByExpandingTildeInPath];
+    [path getCString:(macosx.fontsPath)];
 }
 
 @end
@@ -147,21 +159,53 @@ static NSString *getApplicationName(void)
 /* The main class of the application, the application's delegate */
 @implementation SDLMain
 
+- (IBAction) onAbout:(id)sender
+{
+    NSBundle *mainBundle = [NSBundle mainBundle];
+    NSDictionary *bundleInfo = [mainBundle infoDictionary];
+    NSMutableString *string;
+    NSMutableAttributedString *attributedString;
+    NSMutableDictionary *attributes;
+    
+    /* string attributes */
+    NSMutableParagraphStyle *paragraphStyle = [[NSParagraphStyle defaultParagraphStyle] mutableCopy];
+    [paragraphStyle setAlignment:NSCenterTextAlignment];
+    attributes = [NSMutableDictionary dictionary];
+    [attributes setObject:[NSFont boldSystemFontOfSize:12] forKey:NSFontAttributeName];
+    [attributes setObject:paragraphStyle forKey:NSParagraphStyleAttributeName];
+    [paragraphStyle release];
+    
+    /* display Tux Paint */
+    string = [bundleInfo objectForKey:@"CFBundleName"];
+    attributedString = [[NSAttributedString alloc] initWithString:string attributes:attributes];
+    [appnameText setAttributedStringValue:attributedString];
+    [attributedString release];
+    
+    /* display version */
+    string = [NSMutableString stringWithString:@"Version "];
+    [string appendString:[bundleInfo objectForKey:@"CFBundleShortVersionString"]];
+    [string appendString:@" ("];
+    [string appendString:[bundleInfo objectForKey:@"CFBundleVersion"]];
+    [string appendString:@")"];
+    [versionText setStringValue:string];
+    
+    /* display credits */
+    NSString *filePath = [mainBundle pathForResource:@"credits" ofType:@"txt"];
+    string = [NSString stringWithContentsOfFile:filePath];
+    [attributes setObject:[NSFont systemFontOfSize:10] forKey:NSFontAttributeName];
+    attributedString = [[NSMutableAttributedString alloc] initWithString:string attributes:attributes];
+    [[acknowledgmentsText textStorage] setAttributedString:attributedString];
+    [attributedString release];
+    [acknowledgmentsText activateURLs];
+    [acknowledgmentsText setEditable:NO];
+
+    [aboutWindow makeKeyAndOrderFront:sender];
+}
+
+
 - (IBAction) onNew:(id)sender
 {
 	[self sendSDLControlKeystroke:SDLK_n];
-	/*
-	[NSApp beginSheet:nameWindow
-	   modalForWindow:[NSApp mainWindow]
-		modalDelegate:nil
-	   didEndSelector:nil
-		  contextInfo:nil];
-	
-	[NSApp runModalForWindow:nameWindow];
-	
-	[NSApp endSheet:nameWindow];
-	[nameWindow orderOut:self];
-	 */
 }
 
 - (IBAction) onOpen:(id)sender
@@ -183,7 +227,7 @@ static NSString *getApplicationName(void)
 
 - (IBAction) onPageSetup:(id)sender
 {
-    DisplayPageSetup();
+    [self sendSDLControlShiftKeystroke:SDLK_p];
 }
 
 - (IBAction) onUndo:(id)sender
@@ -204,6 +248,8 @@ static NSString *getApplicationName(void)
 
 - (IBAction) onQuit:(id)sender
 {
+    [[NSUserDefaults standardUserDefaults] synchronize];
+    
     /* Post a SDL_QUIT event */
     SDL_Event event;
     event.type = SDL_QUIT;
@@ -219,6 +265,15 @@ static NSString *getApplicationName(void)
 	SDL_PushEvent(&event);	
 }
 
+- (void) sendSDLControlShiftKeystroke:(int)key
+{
+	SDL_Event event;
+	event.type = SDL_KEYDOWN;
+	event.key.keysym.sym = key;
+	event.key.keysym.mod = KMOD_CTRL | KMOD_SHIFT;
+	SDL_PushEvent(&event);	
+}
+
 /* Set the working directory to the .app's parent directory */
 - (void) setupWorkingDirectory:(BOOL)shouldChdir
 {
@@ -235,6 +290,24 @@ static NSString *getApplicationName(void)
 	}	
 }
 
+- (void) displayMessage:(NSString*)message andStatus:(NSString*)status withProgressIndicator:(BOOL)progress
+{
+    [messageText setStringValue:message];
+    [messageStatus setStringValue:status];
+    [messagePanel makeKeyAndOrderFront:nil]; 
+    if (progress)
+    {
+        [messageProgress setUsesThreadedAnimation:YES];
+        [messageProgress startAnimation:nil];
+    }
+}
+
+- (void) hideMessage
+{
+    [messageProgress stopAnimation:nil];
+    [messagePanel close];
+}
+
 #if SDL_USE_NIB_FILE
 
 /* Fix menu to contain the real app name instead of "SDL App" */
@@ -257,7 +330,7 @@ static NSString *getApplicationName(void)
         if ([menuItem hasSubmenu])
             [self fixMenu:[menuItem submenu] withAppName:appName];
     }
-    [ aMenu sizeToFit ];
+    [aMenu sizeToFit];
 }
 
 #else
@@ -408,6 +481,106 @@ static void CustomApplicationMain (argc, argv)
 	[bridge preferencesPath];
 }
 
+- (BOOL) installFontconfigFiles
+{
+    NSBundle *bundle = [NSBundle mainBundle];
+    NSString *executable = [bundle pathForAuxiliaryExecutable:@"fcinstaller"];
+    NSString *arguments = [NSString stringWithCString:(macosx.globalPreferencesPath)];
+    
+    char command[4096];
+    sprintf(command, "\"%s\" \"%s\"", [executable cString], [arguments cString]);
+    
+    int result = system(command);
+    
+    return (BOOL)result;
+}
+
+- (BOOL) installFontconfigFilesWithAuthorization
+{
+    OSStatus status;
+    AuthorizationFlags flags = kAuthorizationFlagDefaults;
+    AuthorizationRef authorizationRef;
+    NSBundle *bundle = [NSBundle mainBundle];
+    
+    status = AuthorizationCreate(NULL, kAuthorizationEmptyEnvironment, flags, &authorizationRef);
+    if (status != errAuthorizationSuccess)
+        return status;
+
+    AuthorizationItem items = {kAuthorizationRightExecute, 0, NULL, 0};
+    AuthorizationRights rights = {1, &items};
+        
+    flags = kAuthorizationFlagDefaults | kAuthorizationFlagInteractionAllowed | kAuthorizationFlagPreAuthorize | kAuthorizationFlagExtendRights;
+    status = AuthorizationCopyRights(authorizationRef, &rights, NULL, flags, NULL);
+    
+    if (status == errAuthorizationSuccess)
+    {
+        NSString *fcInstallerPath = [bundle pathForAuxiliaryExecutable:@"fcinstaller"];
+        
+        char executable[2048]; 
+        char *arguments[] = { "/Library/Application Support/TuxPaint", NULL };
+        FILE *communicationsPipe = NULL;
+        
+        strcpy(executable, [fcInstallerPath cString]);
+        
+        flags = kAuthorizationFlagDefaults;
+        status = AuthorizationExecuteWithPrivileges(authorizationRef, executable, flags, arguments, &communicationsPipe);
+    }
+    
+    AuthorizationFree(authorizationRef, kAuthorizationFlagDefaults);
+    return (status == errAuthorizationSuccess); 
+}
+
+- (BOOL) fontconfigFilesAreInstalled
+{
+    NSString *globalPreferencesPath = [NSString stringWithCString:(macosx.globalPreferencesPath)];
+    NSString *fontsPath = [globalPreferencesPath stringByAppendingString:@"/fontconfig/fonts"];
+    NSString *fontsConfInstalledPath = [fontsPath stringByAppendingString:@"/fonts.conf"];
+    NSString *fontsDtdInstalledPath = [fontsPath stringByAppendingString:@"/fonts.dtd"];
+    BOOL filesExist = TRUE;
+ 
+    NSFileManager *fileManager = [NSFileManager defaultManager];
+    filesExist = [fileManager fileExistsAtPath:fontsConfInstalledPath] && [fileManager fileExistsAtPath:fontsDtdInstalledPath];
+    return filesExist;
+}
+
+/* Set up Fontconfig */
+- (void) setupFontconfig
+{
+    /* Tell Fontconfig to use font configuration file in application bundle */
+    setenv ("FONTCONFIG_PATH", [[[NSBundle mainBundle] resourcePath] cString], 1);
+    
+    /* Install font configuration file */
+    /*
+    BOOL filesExist = [self fontconfigFilesAreInstalled];
+    if (!filesExist)
+    {
+        [self installFontconfigFiles];
+        filesExist = [self fontconfigFilesAreInstalled];
+        if (!filesExist)
+        {
+            [self installFontconfigFilesWithAuthorization];
+            filesExist = [self fontconfigFilesAreInstalled];
+            if (!filesExist)
+                exit(-1);
+        }
+    }
+    */
+  
+    /* Determine if Fontconfig cache needs to be built */
+    NSString *globalPreferencesPath = [NSString stringWithCString:(macosx.globalPreferencesPath)];
+    NSString *globalCachePath = [globalPreferencesPath stringByAppendingString:@"/fontconfig/cache"];
+    NSString *userCachePath = [[NSString stringWithString:@"~/.fontconfig"] stringByExpandingTildeInPath];
+    
+    NSFileManager *fileManager = [NSFileManager defaultManager];
+    if (![fileManager fileExistsAtPath:globalCachePath] && ![fileManager fileExistsAtPath:userCachePath])
+    {
+        /* Build Fontconfig cache */
+        displayMessage( MSG_FONT_CACHE );
+        FcBool initSuccess = FcInit();
+        hideMessage();
+    }
+}
+
 /*
  * Catch document open requests...this lets us notice files when the app
  *  was launched by double-clicking a document, or when a document was
@@ -456,16 +629,27 @@ static void CustomApplicationMain (argc, argv)
     return TRUE;
 }
 
+- (BOOL)textView:(NSTextView*)textView clickedOnLink:(id)link atIndex:(unsigned)charIndex 
+{
+    BOOL success;
+    success = [[NSWorkspace sharedWorkspace] openURL: link];
+    return success;
+}
+
 /* Called when the internal event loop has just started running */
 - (void) applicationDidFinishLaunching: (NSNotification *) note
 {
     int status;
+    sdlMain = self;
 	
 	/* Allow Cocoa events to be processed */
 	setenv ("SDL_ENABLEAPPEVENTS", "1", 1);	
 	
 	/* Set up Cocoa to SDL bridge */
 	[self setupBridge];
+    
+    /* Set up Fontconfig */
+    [self setupFontconfig];
 	
     /* Set the working directory to the .app's parent directory */
     [self setupWorkingDirectory:gFinderLaunch];
@@ -474,7 +658,7 @@ static void CustomApplicationMain (argc, argv)
     /* Set the main menu to contain the real app name instead of "SDL App" */
     [self fixMenu:[NSApp mainMenu] withAppName:getApplicationName()];
 #endif
-	
+    
     /* Hand off to main application code */
     gCalledAppMainline = TRUE;
     status = SDL_main (gArgc, gArgv);
@@ -524,13 +708,10 @@ static void CustomApplicationMain (argc, argv)
 
 @end
 
-
-
 #ifdef main
 #  undef main
 #endif
 
-
 /* Main entry point to executable - should *not* be SDL_main! */
 int main (int argc, char **argv)
 {
