@@ -4,7 +4,7 @@
   Calligraphy Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 21, 2007
-  $Id: calligraphy.c,v 1.4 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: calligraphy.c,v 1.10 2009/06/06 16:40:20 secretlondon Exp $
 */
 
 #include <stdio.h>
@@ -60,7 +60,7 @@ int calligraphy_init(magic_api * api)
 {
   char fname[1024];
 
-  snprintf(fname, sizeof(fname), "%s/sounds/magic/calligraphy.wav",
+  snprintf(fname, sizeof(fname), "%s/sounds/magic/calligraphy.ogg",
 	   api->data_directory);
 
   calligraphy_snd = Mix_LoadWAV(fname);
@@ -109,7 +109,7 @@ char * calligraphy_get_name(magic_api * api, int which)
 }
 
 // Return our description, localized:
-char * calligraphy_get_description(magic_api * api, int which)
+char * calligraphy_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(
          gettext_noop("Click and move the mouse around to draw in calligraphy.")));
@@ -252,7 +252,7 @@ void calligraphy_drag(magic_api * api, int which, SDL_Surface * canvas,
   api->playsound(calligraphy_snd, (x * 255) / canvas->w, 255);
 }
 
-void calligraphy_click(magic_api * api, int which,
+void calligraphy_click(magic_api * api, int which, int mode,
 	            SDL_Surface * canvas, SDL_Surface * last,
 	            int x, int y, SDL_Rect * update_rect)
 {
@@ -420,3 +420,15 @@ static float calligraphy_dist(float x1, float y1, float x2, float y2)
   return d;
 }
 
+void calligraphy_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void calligraphy_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int calligraphy_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT);
+}
