@@ -4,7 +4,7 @@
   Cartoon Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 21, 2007
-  $Id: cartoon.c,v 1.7 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: cartoon.c,v 1.11 2008/07/10 20:26:39 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -81,7 +81,7 @@ char * cartoon_get_name(magic_api * api, int which)
 }
 
 // Return our descriptions, localized:
-char * cartoon_get_description(magic_api * api, int which)
+char * cartoon_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(gettext_noop(
 "Click and move the mouse around to turn the picture into a cartoon.")));
@@ -191,7 +191,7 @@ void cartoon_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void cartoon_click(magic_api * api, int which,
+void cartoon_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -223,3 +223,15 @@ int cartoon_requires_colors(magic_api * api, int which)
   return 0;
 }
 
+void cartoon_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void cartoon_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int cartoon_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT); /* FIXME - Can also be turned into a full-image effect */
+}
