@@ -4,7 +4,7 @@
   Distortion Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: October 24, 2007
-  $Id: distortion.c,v 1.3 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: distortion.c,v 1.8 2008/08/26 03:52:51 secretlondon Exp $
 */
 
 /* Inclusion of header files: */
@@ -124,9 +124,9 @@ char * distortion_get_name(magic_api * api, int which)
 
 // Report our "Magic" tool descriptions
 
-char * distortion_get_description(magic_api * api, int which)
+char * distortion_get_description(magic_api * api, int which, int mode)
 {
-  return(strdup(gettext_noop("Click and drag the mouse to cause a distortion in your picture.")));
+  return(strdup(gettext_noop("Click and drag the mouse to cause distortion in your picture.")));
 }
 
 // Report whether we accept colors
@@ -150,7 +150,7 @@ void distortion_shutdown(magic_api * api)
 
 // Affect the canvas on click:
 
-void distortion_click(magic_api * api, int which,
+void distortion_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * snapshot,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -226,3 +226,15 @@ static void distortion_line_callback(void * ptr, int which,
   }
 }
 
+void distortion_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void distortion_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int distortion_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT);
+}
