@@ -4,7 +4,7 @@
   Emboss Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 7, 2007
-  $Id: emboss.c,v 1.7 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: emboss.c,v 1.11 2008/07/10 20:26:39 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -77,7 +77,7 @@ char * emboss_get_name(magic_api * api, int which)
 }
 
 // Return our descriptions, localized:
-char * emboss_get_description(magic_api * api, int which)
+char * emboss_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(gettext_noop("Click and drag the mouse to emboss the picture.")));
 }
@@ -147,7 +147,7 @@ void emboss_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void emboss_click(magic_api * api, int which,
+void emboss_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -179,3 +179,15 @@ int emboss_requires_colors(magic_api * api, int which)
   return 0;
 }
 
+void emboss_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void emboss_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int emboss_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT); /* FIXME - Can also be turned into a full-image effect */
+}
