@@ -4,7 +4,7 @@
   Flower Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 21, 2007
-  $Id: flower.c,v 1.7 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: flower.c,v 1.11 2008/07/10 20:26:39 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -125,7 +125,7 @@ char * flower_get_name(magic_api * api, int which)
 }
 
 // Return our descriptions, localized:
-char * flower_get_description(magic_api * api, int which)
+char * flower_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(gettext_noop("Click and drag to draw a flower stalk. Let go to finish the flower.")));
 }
@@ -192,7 +192,7 @@ void flower_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void flower_click(magic_api * api, int which,
+void flower_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -594,3 +594,15 @@ static void flower_colorize_petals(magic_api * api)
   SDL_UnlockSurface(flower_petals);
 }
 
+void flower_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void flower_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int flower_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT);
+}
