@@ -4,7 +4,7 @@
   Foam Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 21, 2007
-  $Id: foam.c,v 1.6 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: foam.c,v 1.10 2008/07/10 20:26:39 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -105,7 +105,7 @@ char * foam_get_name(magic_api * api, int which)
 }
 
 // Return our descriptions, localized:
-char * foam_get_description(magic_api * api, int which)
+char * foam_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(gettext_noop("Click and drag the mouse to cover an area with foamy bubbles.")));
 }
@@ -161,7 +161,7 @@ void foam_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void foam_click(magic_api * api, int which,
+void foam_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -417,3 +417,15 @@ int foam_requires_colors(magic_api * api, int which)
   return 0;  /* FIXME: Would be nice to tint the bubbles */
 }
 
+void foam_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void foam_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int foam_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT);
+}
