@@ -4,7 +4,7 @@
   Kaleidoscope Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: November 21, 2007
-  $Id: kalidescope.c,v 1.7 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: kalidescope.c,v 1.11 2008/07/10 20:26:39 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -78,7 +78,7 @@ char * kalidescope_get_name(magic_api * api, int which)
 }
 
 // Return our descriptions, localized:
-char * kalidescope_get_description(magic_api * api, int which)
+char * kalidescope_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(gettext_noop("Click and drag the mouse to draw with symmetric brushes (a kaleidoscope).")));
 }
@@ -128,7 +128,7 @@ void kalidescope_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void kalidescope_click(magic_api * api, int which,
+void kalidescope_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -164,3 +164,15 @@ int kalidescope_requires_colors(magic_api * api, int which)
   return 1;
 }
 
+void kalidescope_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void kalidescope_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int kalidescope_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT);
+}
