@@ -4,7 +4,7 @@
   Light Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 21, 2007
-  $Id: light.c,v 1.4 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: light.c,v 1.8 2008/07/10 20:26:40 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -85,7 +85,7 @@ char * light_get_name(magic_api * api, int which)
 }
 
 // Return our descriptions, localized:
-char * light_get_description(magic_api * api, int which)
+char * light_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(gettext_noop("Click and drag to draw a beam of light on your picture.")));
 }
@@ -171,7 +171,7 @@ void light_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void light_click(magic_api * api, int which,
+void light_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -207,3 +207,15 @@ int light_requires_colors(magic_api * api, int which)
   return 1;
 }
 
+void light_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void light_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int light_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT);
+}
