@@ -4,7 +4,7 @@
   Negative Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 7, 2007
-  $Id: negative.c,v 1.9 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: negative.c,v 1.14 2008/11/01 21:49:11 secretlondon Exp $
 */
 
 #include <stdio.h>
@@ -73,10 +73,16 @@ char * negative_get_name(magic_api * api, int which)
 }
 
 // Return our description, localized:
-char * negative_get_description(magic_api * api, int which)
+char * negative_get_description(magic_api * api, int which, int mode)
 {
-  return(strdup(
-         gettext_noop("Click and move the mouse around to draw a negative.")));
+  if (mode == MODE_PAINT)
+    return(strdup(
+           gettext_noop("Click and move the mouse around to make your painting negative."))); /* Does this make more sense? */
+  else if (mode == MODE_FULLSCREEN)
+    return(strdup(
+           gettext_noop("Click to turn your painting into its negative.")));
+  else
+    return(NULL);
 }
 
 // Callback that does the negative color effect on a circle centered around x,y
@@ -125,17 +131,43 @@ void negative_drag(magic_api * api, int which, SDL_Surface * canvas,
   update_rect->h = (y + 16) - update_rect->h;
 
   api->playsound(negative_snd, (x * 255) / canvas->w, 255);
-  
+
+
   SDL_UnlockSurface(canvas);
   SDL_UnlockSurface(last);
 }
 
 // Ask Tux Paint to call our 'do_negative()' callback at a single point
-void negative_click(magic_api * api, int which,
+void negative_click(magic_api * api, int which, int mode,
 	            SDL_Surface * canvas, SDL_Surface * last,
 	            int x, int y, SDL_Rect * update_rect)
 {
-  negative_drag(api, which, canvas, last, x, y, x, y, update_rect);
+  if (mode == MODE_PAINT)
+    negative_drag(api, which, canvas, last, x, y, x, y, update_rect);
+  else
+  {
+    int xx, yy;
+    Uint8 r, g, b;
+
+    for (yy = 0; yy < canvas->h; yy++)
+    {
+      for (xx = 0; xx < canvas->w; xx++)
+      {
+        SDL_GetRGB(api->getpixel(last, xx, yy), last->format, &r, &g, &b);
+
+        r = 0xFF - r;
+        g = 0xFF - g;
+        b = 0xFF - b;
+
+        api->putpixel(canvas, xx, yy, SDL_MapRGB(canvas->format, r, g, b));
+      }
+    }
+
+    update_rect->x = 0;
+    update_rect->y = 0;
+    update_rect->w = canvas->w;
+    update_rect->h = canvas->h;
+  }
 }
 
 
@@ -163,3 +195,15 @@ int negative_requires_colors(magic_api * api, int which)
   return 0;
 }
 
+void negative_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void negative_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int negative_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT | MODE_FULLSCREEN);
+}
