@@ -4,7 +4,7 @@
   Rainbow Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 7, 2007
-  $Id: rainbow.c,v 1.8 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: rainbow.c,v 1.12 2008/07/10 20:26:40 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -108,7 +108,7 @@ char * rainbow_get_name(magic_api * api, int which)
 }
 
 // Return our descriptions, localized:
-char * rainbow_get_description(magic_api * api, int which)
+char * rainbow_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(
 	   gettext_noop("You can draw in rainbow colors!")));
@@ -160,7 +160,7 @@ void rainbow_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void rainbow_click(magic_api * api, int which,
+void rainbow_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y,
 		   SDL_Rect * update_rect)
@@ -193,3 +193,15 @@ int rainbow_requires_colors(magic_api * api, int which)
   return 0;
 }
 
+void rainbow_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void rainbow_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int rainbow_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT);
+}
