@@ -4,7 +4,7 @@
   Ripples Magic Tool Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 7, 2007
-  $Id: ripples.c,v 1.4 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: ripples.c,v 1.8 2008/07/10 20:26:40 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -82,7 +82,7 @@ char * ripples_get_name(magic_api * api, int which)
 }
 
 // Return our descriptions, localized:
-char * ripples_get_description(magic_api * api, int which)
+char * ripples_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(gettext_noop("Click to make ripples appear over your picture.")));
 }
@@ -113,7 +113,7 @@ static void ripples_linecb(void * ptr, int which,
 }
 
 // Affect the canvas on click:
-void ripples_click(magic_api * api, int which,
+void ripples_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -177,3 +177,15 @@ int ripples_requires_colors(magic_api * api, int which)
   return 0;
 }
 
+void ripples_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void ripples_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int ripples_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT);
+}
