@@ -5,7 +5,7 @@
   Tux Paint - A simple drawing program for children.
 
   by Albert Cahalan <albert@users.sf.net>
-  Copyright (c) 2002-2007 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2008 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -24,8 +24,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: August 7, 2007
-  $Id: smudge.c,v 1.7 2008/06/26 15:13:57 dolphin6k Exp $
+  Last updated: July 8, 2008
+  $Id: smudge.c,v 1.11 2008/07/10 20:26:40 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -78,7 +78,7 @@ char * smudge_get_name(magic_api * api, int which)
 }
 
 // Return our descriptions, localized:
-char * smudge_get_description(magic_api * api, int which)
+char * smudge_get_description(magic_api * api, int which, int mode)
 {
   return(strdup(gettext_noop(
 "Click and move the mouse around to smudge the picture.")));
@@ -140,7 +140,7 @@ void smudge_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void smudge_click(magic_api * api, int which,
+void smudge_click(magic_api * api, int which, int mode,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -172,3 +172,15 @@ int smudge_requires_colors(magic_api * api, int which)
   return 0;
 }
 
+void smudge_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+void smudge_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+{
+}
+
+int smudge_modes(magic_api * api, int which)
+{
+  return(MODE_PAINT);
+}
