@@ -4,9 +4,9 @@
   For Tux Paint
   Bitmapped mouse pointer (cursor)
 
-  Copyright (c) 2002-2006 by Bill Kendrick and others
+  Copyright (c) 2002-2007 by Bill Kendrick and others
   bill@newbreedsoftware.com
-  http://www.newbreedsoftware.com/tuxpaint/
+  http://www.tuxpaint.org/
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  June 14, 2002 - February 18, 2006
-  $Id: cursor.c,v 1.3 2006/08/27 21:00:55 wkendrick Exp $
+  June 14, 2002 - May 15, 2007
+  $Id: cursor.c,v 1.4 2007/05/16 01:11:34 wkendrick Exp $
 */
 
 #include "cursor.h"
@@ -36,7 +36,7 @@ SDL_Cursor *cursor_hand, *cursor_arrow, *cursor_watch,
   *cursor_up, *cursor_down, *cursor_tiny, *cursor_crosshair,
   *cursor_brush, *cursor_wand, *cursor_insertion, *cursor_rotate;
 
-int no_fancy_cursors;
+int no_fancy_cursors, hide_cursor;
 
 void do_setcursor(SDL_Cursor * c)
 {
@@ -66,7 +66,7 @@ void do_setcursor(SDL_Cursor * c)
   UNUSED(arrow_bits);
   UNUSED(arrow_mask_bits);
 
-  if (!no_fancy_cursors)
+  if (!hide_cursor && !no_fancy_cursors)
     SDL_SetCursor(c);
 }
 
