@@ -1,5 +1,25 @@
 /*
   dirwalk.c
+
+  Copyright (c) 2009
+  http://www.tuxpaint.org/
+
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  (See COPYING.txt)
+
+  $Id: dirwalk.c,v 1.16 2009/06/18 02:43:31 albert Exp $
 */
 
 #include <stdio.h>
@@ -48,7 +68,7 @@
 ///////////////// directory walking callers and callbacks //////////////////
 
 void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
-		       unsigned dirlen, tp_ftw_str * files, unsigned i)
+		       unsigned dirlen, tp_ftw_str * files, unsigned i, char * locale)
 {
   dirlen = dirlen;
 
@@ -87,8 +107,22 @@ void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
       char fname[512];
       TuxPaint_Font *font;
       snprintf(fname, sizeof fname, "%s/%s", dir, files[i].str);
-//printf("Loading font: %s\n", fname);
-      font = TuxPaint_Font_OpenFont("", fname, text_sizes[text_size]);
+/* printf("Loading font: %s  (locale is: %s)\n", fname, (locale != NULL ? locale : "NULL")); */
+      if (locale != NULL && strstr(fname, "locale") != NULL && all_locale_fonts == 0)
+      {
+        char fname_check[512];
+        /* We're (probably) loading from our locale fonts folder; ONLY load our locale's font */
+        snprintf(fname_check, sizeof fname_check, "%s/%s.ttf", dir, locale);
+/* printf("checking vs \"%s\" vs \"%s\"\n", fname_check, fname); */
+        if (strcmp(fname, fname_check) == 0)
+          font = TuxPaint_Font_OpenFont("", fname, text_sizes[text_size]);
+        else
+          font = NULL;
+      }
+      else
+      {
+        font = TuxPaint_Font_OpenFont("", fname, text_sizes[text_size]);
+      }
       if (font)
       {
 	const char *restrict const family = TuxPaint_Font_FontFaceFamilyName(font);
@@ -105,25 +139,32 @@ void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
 	       (unsigned int) font, (unsigned int) font->ttf_font);
 #endif
 
+	// These fonts crash Tux Paint via a library bug.
+	int blacklisted = !strcmp("Zapfino", family) || !strcmp("Elvish Ring NFI", family);
+
 	// First, the blacklist. We list font families that can crash Tux Paint
 	// via bugs in the SDL_ttf library. We also test fonts to be sure that
 	// they have both uppercase and lowercase letters. Note that we do not
 	// test for "Aa", because it is OK if uppercase and lowercase are the
 	// same (but not nice -- such fonts get a low score later).
 	//
-	// We test the alphabet twice, to help with translation. If the users
-	// will be unable to type ASCII letters, then both Line X and Line Y
-	// should be translated. Otherwise, only Line X should be translated
-	// and the ASCII-only fonts should be given bad scores in the scoring
-	// code below (the best scores going to fonts that support both).
-	
-	// Line X
-	if (strcmp("Zapfino", family) && strcmp("Elvish Ring NFI", family) && ((charset_works(font, gettext("qx")) && charset_works(font, gettext("QX")))
+	// Most locales leave the blacklist strings alone: "QX" and "qx"
+	// (it is less destructive to use the scoring strings instead)
+	//
+	// Locales that absolutely require all fonts to have some
+	// extra characters should use "QX..." and "qx...", where "..."
+	// are some characters you absolutely require in all fonts.
+	//
+	// Locales with absolutely NO use for ASCII may use "..." and "...",
+	// where "..." are some characters you absolutely require in
+	// all fonts. This would be the case for a locale in which it is
+	// impossible for a user to type ASCII letters.
+	//
+	// Most translators should use scoring instead.
+	if(!charset_works(font, gettext("qx")) || !charset_works(font, gettext("QX")))
+		blacklisted = 1;
 
-	// Line Y
-									       || (charset_works(font, gettext("qy")) && charset_works(font, gettext("QY")))
-	    ))
-	{
+	if(!blacklisted){
 	  if (num_font_styles == num_font_styles_max)
 	  {
 	    num_font_styles_max = num_font_styles_max * 5 / 4 + 30;
@@ -137,6 +178,9 @@ void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
 	  user_font_styles[num_font_styles]->filename = files[i].str;	// steal it (mark NULL below)
 	  user_font_styles[num_font_styles]->family = strdup(family);
 	  user_font_styles[num_font_styles]->style = strdup(style);
+          user_font_styles[num_font_styles]->score = 0;
+
+	  // TODO: weight specification
 
 	  // Now we score fonts to ensure that the best ones will be placed at
 	  // the top of the list. The user will see them first. This sorting is
@@ -144,14 +188,14 @@ void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
 	  // Translators should do whatever is needed to put crummy fonts last.
 	  
 	  // distinct uppercase and lowercase (e.g., 'o' vs. 'O')
-	  user_font_styles[num_font_styles]->score = charset_works(font, gettext("oO"));
-
-	  // uncommon punctuation (e.g., '@', '#', '*', etc.)
-	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("`\%_@$~#{}<>^&*"));
+	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("oO"));
 
 	  // common punctuation (e.g., '?', '!', '.', ',', etc.)
 	  user_font_styles[num_font_styles]->score += charset_works(font, gettext(",.?!"));
 
+	  // uncommon punctuation (e.g., '@', '#', '*', etc.)
+	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("`\%_@$~#{<(^&*"));
+
 	  // digits (e.g., '0', '1' and '7')
 	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("017"));
 
@@ -161,10 +205,22 @@ void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
 	  // distinct line-like characters (e.g., 'l' (lowercase elle) vs. '1' (one) vs. 'I' (capital aye))
 	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("1Il|"));
 
+	  // translation spares -- design not finalized
+#if 0
+	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("<1>spare-1a"));
+	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("<1>spare-1b"));
+	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("<9>spare-9a"))*9;
+	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("<9>spare-9b"))*9;
+#endif
+
+// this really should be dynamic, avoiding the need for a special build
 #ifdef OLPC_XO
+	  // Maybe German adds a "\xc2\xb7" (middle dot) and colon here? The key wouldn't change though.
 	  user_font_styles[num_font_styles]->score += charset_works(font, "\xc3\x97\xc3\xb7");	// multiply and divide
 #endif
 
+	  // FIXME: add topology tests ('A' has one hole, 'B' has two holes, etc.)
+
 	  num_font_styles++;
 //printf("Accepted: %s, %s, %s, score(%d)\n", files[i].str, family, style, user_font_styles[num_font_styles]->score);
 	  files[i].str = NULL;	// so free() won't crash -- we stole the memory
@@ -205,7 +261,8 @@ void tp_ftw(SDL_Surface * screen, char *restrict const dir, unsigned dirlen,
 	    int rsrc, void (*fn) (SDL_Surface * screen,
 				  const char *restrict const dir,
 				  unsigned dirlen, tp_ftw_str * files,
-				  unsigned count))
+				  unsigned count, char * locale),
+            char * locale)
 {
   DIR *d;
   unsigned num_file_names = 0;
@@ -329,7 +386,7 @@ void tp_ftw(SDL_Surface * screen, char *restrict const dir, unsigned dirlen,
     }
     free(file_names);
 #else
-    fn(screen, dir, dirlen, file_names, num_file_names);
+    fn(screen, dir, dirlen, file_names, num_file_names, locale);
 #endif
   }
 
@@ -340,7 +397,7 @@ void tp_ftw(SDL_Surface * screen, char *restrict const dir, unsigned dirlen,
     {
       memcpy(dir + dirlen, dir_names[num_dir_names].str,
 	     dir_names[num_dir_names].len + 1);
-      tp_ftw(screen, dir, dirlen + dir_names[num_dir_names].len, rsrc, fn);
+      tp_ftw(screen, dir, dirlen + dir_names[num_dir_names].len, rsrc, fn, locale);
       free(dir_names[num_dir_names].str);
     }
     free(dir_names);
