@@ -1,5 +1,25 @@
 /*
   fonts.c
+
+  Copyright (c) 2009
+  http://www.tuxpaint.org/
+
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  (See COPYING.txt)
+
+  $Id: fonts.c,v 1.21 2009/06/06 18:22:00 wkendrick Exp $
 */
 
 #include <stdio.h>
@@ -100,6 +120,7 @@ SDL_Thread *font_thread;
 
 
 int no_system_fonts;
+int all_locale_fonts;
 volatile long font_thread_done = 0, font_thread_aborted = 0;
 volatile long waiting_for_fonts = 0;
 int font_scanner_pid;
@@ -119,6 +140,9 @@ int text_state = 0;
 unsigned text_size = 4;		// initial text size
 
 
+void loadfonts_locale_filter(SDL_Surface * screen, const char *const dir, char * locale);
+
+
 /* Unfortunately, there is a bug in SDL_ttf-2.0.6, the current version
    that causes a segmentation fault if an attempt is made to call
    TTF_OpenFont() with the filename of a font that doesn't exist. This
@@ -416,7 +440,7 @@ void reliable_read(int fd, void *buf, size_t count)
 }
 
 
-void run_font_scanner(SDL_Surface * screen)
+void run_font_scanner(SDL_Surface * screen, char * locale)
 {
   int sv[2];
   int size, i;
@@ -442,7 +466,7 @@ void run_font_scanner(SDL_Surface * screen)
   sched_yield();		// try to let the parent run right now
   SDL_Init(SDL_INIT_NOPARACHUTE);
   TTF_Init();
-  load_user_fonts(screen, NULL);
+  load_user_fonts(screen, NULL, locale);
 
   size = 0;
   i = num_font_families;
@@ -607,8 +631,8 @@ void receive_some_font_info(SDL_Surface * screen)
 
   show_progress_bar(screen);
   walk = buf;
-  num_font_families = *walk++;
-  num_font_families += *walk++ << 8u;
+  num_font_families = *(unsigned char *)walk++;
+  num_font_families += *(unsigned char *)walk++ << 8u;
 #ifdef DEBUG
   printf("Got %u bytes with %u families.\n", buf_fill, num_font_families);
 #endif
@@ -657,13 +681,13 @@ void receive_some_font_info(SDL_Surface * screen)
 #endif
 
 
-int load_user_fonts(SDL_Surface * screen, void *vp)
+int load_user_fonts(SDL_Surface * screen, void *vp, char * locale)
 {
   char *homedirdir;
 
   (void) vp;			// junk passed by threading library
 
-  loadfonts(screen, DATA_PREFIX "fonts");
+  loadfonts_locale_filter(screen, DATA_PREFIX "fonts", locale);
 
   if (!no_system_fonts)
   {
@@ -1365,12 +1389,17 @@ TuxPaint_Font *getfonthandle(int desire)
 
 
 void loadfonts(SDL_Surface * screen, const char *const dir)
+{
+  loadfonts_locale_filter(screen, dir, NULL);
+}
+
+void loadfonts_locale_filter(SDL_Surface * screen, const char *const dir, char * locale)
 {
   char buf[TP_FTW_PATHSIZE];
   unsigned dirlen = strlen(dir);
 
   memcpy(buf, dir, dirlen);
-  tp_ftw(screen, buf, dirlen, 1, loadfont_callback);
+  tp_ftw(screen, buf, dirlen, 1, loadfont_callback, locale);
 }
 
 
@@ -1470,6 +1499,7 @@ int charset_works(TuxPaint_Font * font, const char *s)
     }
 #endif
 
+/* FIXME: Should the following be in an "#else" block!? -bjk 2009.06.01 */
     if (font->typ == FONT_TYPE_TTF)
     {
       tmp_surf = TTF_RenderUTF8_Blended(font->ttf_font, c, black);
