@@ -23,9 +23,9 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  $Id: i18n.c,v 1.50 2008/06/27 20:20:06 wkendrick Exp $
+  $Id: i18n.c,v 1.54 2009/01/23 22:19:52 wkendrick Exp $
 
-  June 14, 2002 - June 27, 2008
+  June 14, 2002 - October 26, 2008
 */
 
 #include <stdio.h>
@@ -114,8 +114,10 @@ const char *lang_prefixes[NUM_LANGS] = {
   "ro",
   "ru",
   "rw",
+  "shs",
   "sk",
   "sl",
+  "son",
   "sq",
   "sr",
   "sv",
@@ -178,7 +180,7 @@ char *langstr;
 int need_own_font;
 int need_right_to_left;
 int need_right_to_left_word;
-const char *lang_prefix;
+const char *lang_prefix, *short_lang_prefix;
 
 const language_to_locale_struct language_to_locale_array[] = {
   {"english", "C"},
@@ -283,10 +285,13 @@ const language_to_locale_struct language_to_locale_array[] = {
   {"romanian", "ro_RO.UTF-8"},
   {"russian", "ru_RU.UTF-8"},
   {"russkiy", "ru_RU.UTF-8"},
+  {"serbian", "sr_YU.UTF-8"},
+  {"shuswap", "shs_CA.UTF-8"},
+  {"secwepemctin", "shs_CA.UTF-8"},
   {"slovak", "sk_SK.UTF-8"},
   {"slovenian", "sl_SI.UTF-8"},
   {"slovensko", "sl_SI.UTF-8"},
-  {"serbian", "sr_YU.UTF-8"},
+  {"songhay", "son.UTF-8"},
   {"swedish", "sv_SE.UTF-8"},
   {"svenska", "sv_SE.UTF-8"},
   {"swahili", "sw_TZ.UTF-8"},
@@ -303,7 +308,8 @@ const language_to_locale_struct language_to_locale_array[] = {
   {"chinese", "zh_CN.UTF-8"},
   {"simplified-chinese", "zh_CN.UTF-8"},
   {"traditional-chinese", "zh_TW.UTF-8"},
-  {"zapoteco", "zw_MX.UTF-8"},
+  {"zapotec", "zam.UTF-8"},
+  {"miahuatlan-zapotec", "zam.UTF-8"},
   {"khmer", "km_KH.UTF-8"}
 };
 
@@ -344,7 +350,7 @@ void ctype_utf8(void)
 
 int set_current_language(void)
 {
-  char *loc;
+  char *loc, *baseloc;
   int i, found;
   int y_nudge;
 
@@ -396,10 +402,26 @@ int set_current_language(void)
 
   if (loc != NULL)
   {
+    baseloc = strdup(loc);
+    if (strchr(baseloc, '.') != NULL)
+      strcpy(strchr(baseloc, '.'), "\0");
+
+
     /* Which, if any, of the locales is it? */
 
     found = 0;
 
+    for (i = 0; i < NUM_LANGS && found == 0; i++)
+    {
+      // Case-insensitive (both "pt_BR" and "pt_br" work, etc.)
+      if (strlen(baseloc) == strlen(lang_prefixes[i]) &&
+          strncasecmp(baseloc, lang_prefixes[i], strlen(lang_prefixes[i])) == 0)
+      {
+	langint = i;
+	found = 1;
+      }
+    }
+
     for (i = 0; i < NUM_LANGS && found == 0; i++)
     {
       // Case-insensitive (both "pt_BR" and "pt_br" work, etc.)
@@ -411,10 +433,15 @@ int set_current_language(void)
     }
   }
 
-
   /* FIXME: These don't work because we have the wrong langint...!? -bjk 2008.02.19 */
 
   lang_prefix = lang_prefixes[langint];
+
+  short_lang_prefix = strdup(lang_prefix);
+  /* When in doubt, cut off country code */
+  if (strchr(short_lang_prefix, '_') != NULL)
+    strcpy(strchr(short_lang_prefix, '_'), "\0");
+
   need_own_font = search_int_array(langint, lang_use_own_font);
   need_right_to_left = search_int_array(langint, lang_use_right_to_left);
   need_right_to_left_word = search_int_array(langint, lang_use_right_to_left_word);
@@ -425,7 +452,7 @@ int set_current_language(void)
     if (lang_y_nudge[i][0] == langint)
     {
       y_nudge = lang_y_nudge[i][1];
-      printf("y_nudge = %d\n", y_nudge);
+      //printf("y_nudge = %d\n", y_nudge);
     }
   }
 
@@ -516,9 +543,11 @@ void show_lang_usage(FILE * f, const char *const prg)
 /* ru */ "  russian      russkiy\n"
 /* gd */ "  scottish     scottish-gaelic        ghaidhlig\n"
 /* sr */ "  serbian\n"
+/* shs */ "  shuswap      secwepemctin\n"
 /* sk */ "  slovak\n"
 /* sl */ "  slovenian    slovensko\n"
 /* en_ZA */ "  southafrican-english\n"
+/* son */ "  songhay\n"
 /* es */ "  spanish      espanol\n"
 /* sw */ "  swahili\n"
 /* sv */ "  swedish      svenska\n"
@@ -536,7 +565,7 @@ void show_lang_usage(FILE * f, const char *const prg)
 /* wo */ "  wolof\n"
 /* cy */ "  welsh        cymraeg\n"
 /* xh */ "  xhosa\n"
-/* zw */ "  zapoteco\n"
+/* zam */"  zapotec      miahuatlan-zapotec\n"
 	  "\n", prg);
 }
 
@@ -608,8 +637,10 @@ void show_locale_usage(FILE * f, const char *const prg)
 	  "  ro_RO   (Romanian)\n"
 	  "  ru_RU   (Russian      Russkiy)\n"
 	  "  rw_RW   (Kinyarwanda)\n"
+          "  shs_CA  (Shuswap      Secwepemctin)\n"
 	  "  sk_SK   (Slovak)\n"
 	  "  sl_SI   (Slovenian)\n"
+          "  son     (Songhay)\n"
 	  "  sq_AL   (Albanian)\n"
 	  "  sr_YU   (Serbian)\n"
 	  "  es_ES   (Spanish      Espanol)\n"
@@ -630,7 +661,7 @@ void show_locale_usage(FILE * f, const char *const prg)
 	  "  wo_SN   (Wolof)\n"
 	  "  cy_GB   (Welsh        Cymraeg)\n"
 	  "  xh_ZA   (Xhosa)\n"
-	  "  zw_MX   (Zapoteco)\n"
+	  "  zam     (Zapoteco-Miahuatlan)\n"
 	  "\n", prg);
 }
 
