@@ -6,7 +6,7 @@
   (for non-Windows, non-Mac OS X, non-BeOS platforms, e.g. Linux)
   (moved from tuxpaint.c in 0.9.17)
 
-  Copyright (c) 2007 by Bill Kendrick and others
+  Copyright (c) 2009 by Bill Kendrick and others
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -36,8 +36,8 @@
     implied warranty.
 
 
-  June 24, 2007 - July 17, 2007
-  $Id: postscript_print.c,v 1.4 2007/07/18 20:13:13 wkendrick Exp $
+  June 24, 2007 - January 29, 2009
+  $Id: postscript_print.c,v 1.7 2009/01/29 20:51:37 wkendrick Exp $
 */
 
 #include "postscript_print.h"
@@ -50,6 +50,7 @@
 #include <time.h>
 #include <paper.h>
 #include <math.h>
+#include <errno.h>
 
 #ifndef PAPER_H
 #error "---------------------------------------------------"
@@ -61,6 +62,8 @@
 
 #include "pixels.h"
 
+#define MARGIN 36 /* Margin to put around image, in points (inch/72) (36pt = 0.5") */
+
 #define my_min(x,y) ((x < y) ? (x) : (y))
 
 int f2int(float f);
@@ -81,7 +84,8 @@ int do_ps_save(FILE * fi,
 		// const char *restrict const fname,
 		const char * fname,
 		SDL_Surface * surf,
-		char * pprsize)
+		char * pprsize,
+                int is_pipe)
 {
   const struct paper * ppr;
   int img_w = surf->w;
@@ -183,8 +187,8 @@ int do_ps_save(FILE * fi,
 
   /* Determine scale: */
 
-  scale = my_min(((float) ppr_w / (float) r_img_w),
-		 ((float) ppr_h / (float) r_img_h)) * (72.0 / 100.0);
+  scale = my_min(((float) (ppr_w - (MARGIN * 2)) / (float) r_img_w),
+         ((float) (ppr_h - (MARGIN * 2)) / (float) r_img_h));
 
   printed_img_w = r_img_w * scale;
   printed_img_h = r_img_h * scale;
@@ -217,10 +221,8 @@ int do_ps_save(FILE * fi,
 
   fprintf(fi, "%%%%Pages: 1\n");
 
-  fprintf(fi, "%%%%BoundingBox: %d %d %d %d\n",
-	      (int) tlate_x, (int) tlate_y,
-	      (int) (tlate_x + r_img_w + 0.5),
-	      (int) (tlate_y + r_img_h + 0.5));
+  fprintf(fi, "%%%%BoundingBox: 0 0 %d %d\n", (int) (ppr_w + 0.5), (int)
+(ppr_h + 0.5));
 
   fprintf(fi, "%%%%EndComments\n");
 
@@ -255,8 +257,8 @@ int do_ps_save(FILE * fi,
   x and y axes, leaving the origin location and the orientation of the
   axes unchanged. */
   fprintf(fi, "%d.%02d %d.%02d scale\n",
-          f2int(printed_img_w * scale), f2dec(printed_img_w * scale),
-          f2int(printed_img_h * scale), f2dec(printed_img_h * scale));
+          f2int(printed_img_w), f2dec(printed_img_w),
+          f2int(printed_img_h), f2dec(printed_img_h));
 
   /* Rotate the image */
   if (rotate)
@@ -300,8 +302,55 @@ int do_ps_save(FILE * fi,
   fprintf(fi, "%%%%Trailer\n");
   fprintf(fi, "%%%%EOF\n");
 
-  fclose(fi);
-  return 1;
+  if (!is_pipe)
+  {
+    fclose(fi);
+    return 1;
+  }
+  else
+  {
+    pid_t child_pid, w;
+    int status;
+
+    child_pid = pclose(fi);
+
+/* debug */
+/*
+    printf("pclose returned %d\n", child_pid); fflush(stdout);
+    printf("errno = %d\n", errno); fflush(stdout);
+*/
+
+    if (child_pid < 0 || (errno != 0 && errno != EAGAIN)) { /* FIXME: This right? */
+      return 0;
+    } else if (child_pid == 0) {
+      return 1;
+    }
+
+    do
+    {
+      w = waitpid(child_pid, &status, 0);
+
+/* debug */
+/*
+            if (w == -1) { perror("waitpid"); exit(EXIT_FAILURE); }
+            if (WIFEXITED(status)) {
+                printf("exited, status=%d\n", WEXITSTATUS(status));
+            } else if (WIFSIGNALED(status)) {
+                printf("killed by signal %d\n", WTERMSIG(status));
+            } else if (WIFSTOPPED(status)) {
+                printf("stopped by signal %d\n", WSTOPSIG(status));
+            } else if (WIFCONTINUED(status)) {
+                printf("continued\n");
+            }
+*/
+    }
+    while (w != -1 && !WIFEXITED(status) && !WIFSIGNALED(status));
+
+    if (WIFEXITED(status) && WEXITSTATUS(status) != 0) /* Not happy exit */
+      return 0;
+
+    return 1;
+  }
 }
 
 #endif
