@@ -4,12 +4,27 @@
   For Tux Paint
   List of available tools.
 
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  (See COPYING.txt)
+
   Copyright (c) 2002-2007 by Bill Kendrick
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
   June 14, 2002 - July 17, 2007
-  $Id: tools.h,v 1.8 2007/07/26 16:30:36 wkendrick Exp $
+  $Id: tools.h,v 1.9 2009/06/03 20:46:07 wkendrick Exp $
 */
 
 
