@@ -22,7 +22,7 @@
 /* Sept. 30, 2002 - Oct. 17, 2002 */
 /* Oct.  07, 2003 - added banding support */
 /*                - prints using 24-bit (not 32-bit) bitmap */
-/* $Id: win32_print.c,v 1.14 2007/11/11 23:22:24 johnnypops Exp $ */
+/* $Id: win32_print.c,v 1.15 2008/07/10 20:57:25 johnnypops Exp $ */
 
 #include <windows.h>
 #include <direct.h>
@@ -589,3 +589,56 @@ char *get_temp_fname(const char *const name)
   return strdup(f);
 }
 
+/*
+ * Nasty low-level hook into the keyboard. 2K/XP/Vista only.
+ */
+
+static HHOOK g_hKeyboardHook = NULL;
+static int   g_bWindowActive = 0;
+
+LRESULT CALLBACK LowLevelKeyboardProc(int nCode, WPARAM wParam, LPARAM lParam)
+{
+  int bEatKeystroke = 0;
+  KBDLLHOOKSTRUCT *p = (KBDLLHOOKSTRUCT*)lParam;
+
+  if (nCode < 0 || nCode != HC_ACTION)
+    return CallNextHookEx(g_hKeyboardHook, nCode, wParam, lParam); 
+ 
+  switch (wParam) 
+  {
+    case WM_KEYDOWN:  
+    case WM_KEYUP:    
+    {
+      bEatKeystroke = g_bWindowActive && ((p->vkCode == VK_LWIN) || (p->vkCode == VK_RWIN));
+      break;
+    }
+  }
+ 
+  if(bEatKeystroke)
+    return 1;
+  return CallNextHookEx(g_hKeyboardHook, nCode, wParam, lParam);
+}
+
+int InstallKeyboardHook(void)
+{
+  if (g_hKeyboardHook)
+    return -1;
+  g_hKeyboardHook = SetWindowsHookEx(WH_KEYBOARD_LL, LowLevelKeyboardProc, GetModuleHandle(NULL), 0);
+  return g_hKeyboardHook ? 0 : -2;
+}
+
+int RemoveKeyboardHook(void)
+{
+  if (!g_hKeyboardHook)
+    return -1;
+  UnhookWindowsHookEx(g_hKeyboardHook);
+  g_hKeyboardHook = NULL;
+  return 0;
+}
+
+void SetActivationState(int state)
+{
+  g_bWindowActive = state;
+}
+
+
