@@ -4,7 +4,7 @@
 /* John Popplewell <john@johnnypops.demon.co.uk> */
 
 /* Sept. 30, 2002 - Oct. 1, 2002 */
-/* $Id: win32_print.h,v 1.8 2007/04/28 02:52:11 johnnypops Exp $ */
+/* $Id: win32_print.h,v 1.9 2008/07/10 20:57:25 johnnypops Exp $ */
 
 
 #ifndef __WIN32_PRINT_H__
@@ -24,4 +24,9 @@ extern char *GetDefaultSaveDir(const char *suffix);
 extern char *GetSystemFontDir(void);
 extern char *get_temp_fname(const char *const name);
 
+/* keyboard hooking functions */
+extern int  InstallKeyboardHook(void);
+extern int  RemoveKeyboardHook(void);
+extern void SetActivationState(int state);
+
 #endif
